'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var React = require('react');
var utilsCommons = require('@highlight-ui/utils-commons');
var icon = require('@highlight-ui/icon');
var panel = require('@highlight-ui/panel');
var typography = require('@highlight-ui/typography');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var React__default = /*#__PURE__*/_interopDefaultLegacy(React);

/*! *****************************************************************************
Copyright (c) Microsoft Corporation.

Permission to use, copy, modify, and/or distribute this software for any
purpose with or without fee is hereby granted.

THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH
REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,
INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
PERFORMANCE OF THIS SOFTWARE.
***************************************************************************** */

var __assign = function() {
    __assign = Object.assign || function __assign(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p)) t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};

var styles = {"supportBlue":"#0db5df","supportBrown":"#795548","supportDarkBlue":"#0d34a2","supportDarkPurple":"#7d5cb8","supportGreen":"#3c968d","supportGreyDark":"#5a7886","supportLightGreen":"#8bc34a","supportOrange":"#ffa319","supportPastelBlue":"#bbe5f8","supportPastelBrown":"#d9d0cd","supportPastelDarkBlue":"#cfd6ec","supportPastelDarkPurple":"#d5cae9","supportPastelGreen":"#bbe1dd","supportPastelGrey":"#d3dade","supportPastelLightGreen":"#deecce","supportPastelOrange":"#fbe1bb","supportPastelPink":"#f5c3d4","supportPastelPurple":"#e1c5e7","supportPastelRed":"#f8ccc9","supportPastelYellow":"#fbf6ca","supportPink":"#e8467c","supportPurple":"#9f3eb0","supportRed":"#f55549","supportYellow":"#f4e453","colorPicker":"ColorPicker-module__3H6ypMLc__v2-0-8","button":"ColorPicker-module__XBQM5x8U__v2-0-8","focus":"ColorPicker-module__1iX9akK___v2-0-8","active":"ColorPicker-module__3K79GJJ5__v2-0-8","disabled":"ColorPicker-module__2PSNxo4E__v2-0-8","chevron":"ColorPicker-module__2cO2fFV9__v2-0-8","colorDot":"ColorPicker-module___ZbovZGW__v2-0-8","panel":"ColorPicker-module__3aVapG4Z__v2-0-8","title":"ColorPicker-module__1dP4IMl5__v2-0-8","titleRow":"ColorPicker-module__3-oGnvjB__v2-0-8","colorPreviewWrapper":"ColorPicker-module__3pfOd4k3__v2-0-8","colorPreview":"ColorPicker-module__2VFdKwYM__v2-0-8","colorHex":"ColorPicker-module__1wpQiLhG__v2-0-8","optionRow":"ColorPicker-module__27eY5eb7__v2-0-8","colorOption":"ColorPicker-module__19MT-I77__v2-0-8"};

var mainPalette = (function (p) { return p; })([
    {
        identifier: 'supportRed',
        backgroundColor: styles.supportRed,
        highlight: styles.supportRed,
    },
    {
        identifier: 'supportPink',
        backgroundColor: styles.supportPink,
        highlight: styles.supportPink,
    },
    {
        identifier: 'supportPurple',
        backgroundColor: styles.supportPurple,
        highlight: styles.supportPurple,
    },
    {
        identifier: 'supportDarkPurple',
        backgroundColor: styles.supportDarkPurple,
        highlight: styles.supportDarkPurple,
    },
    {
        identifier: 'supportDarkBlue',
        backgroundColor: styles.supportDarkBlue,
        highlight: styles.supportDarkBlue,
    },
    {
        identifier: 'supportBlue',
        backgroundColor: styles.supportBlue,
        highlight: styles.supportBlue,
    },
    {
        identifier: 'supportGreen',
        backgroundColor: styles.supportGreen,
        highlight: styles.supportGreen,
    },
    {
        identifier: 'supportLightGreen',
        backgroundColor: styles.supportLightGreen,
        highlight: styles.supportLightGreen,
    },
    {
        identifier: 'supportYellow',
        backgroundColor: styles.supportYellow,
        highlight: styles.supportYellow,
    },
    {
        identifier: 'supportOrange',
        backgroundColor: styles.supportOrange,
        highlight: styles.supportOrange,
    },
    {
        identifier: 'supportBrown',
        backgroundColor: styles.supportBrown,
        highlight: styles.supportBrown,
    },
    {
        identifier: 'supportGreyDark',
        backgroundColor: styles.supportGreyDark,
        highlight: styles.supportGreyDark,
    },
]);
var pastelPalette = (function (p) { return p; })([
    {
        identifier: 'supportPastelRed',
        backgroundColor: styles.supportPastelRed,
        highlight: styles.supportRed,
    },
    {
        identifier: 'supportPastelPink',
        backgroundColor: styles.supportPastelPink,
        highlight: styles.supportPink,
    },
    {
        identifier: 'supportPastelPurple',
        backgroundColor: styles.supportPastelPurple,
        highlight: styles.supportPurple,
    },
    {
        identifier: 'supportPastelDarkPurple',
        backgroundColor: styles.supportPastelDarkPurple,
        highlight: styles.supportDarkPurple,
    },
    {
        identifier: 'supportPastelDarkBlue',
        backgroundColor: styles.supportPastelDarkBlue,
        highlight: styles.supportDarkBlue,
    },
    {
        identifier: 'supportPastelBlue',
        backgroundColor: styles.supportPastelBlue,
        highlight: styles.supportBlue,
    },
    {
        identifier: 'supportPastelGreen',
        backgroundColor: styles.supportPastelGreen,
        highlight: styles.supportGreen,
    },
    {
        identifier: 'supportPastelLightGreen',
        backgroundColor: styles.supportPastelLightGreen,
        highlight: styles.supportLightGreen,
    },
    {
        identifier: 'supportPastelYellow',
        backgroundColor: styles.supportPastelYellow,
        highlight: styles.supportYellow,
    },
    {
        identifier: 'supportPastelOrange',
        backgroundColor: styles.supportPastelOrange,
        highlight: styles.supportOrange,
    },
    {
        identifier: 'supportPastelBrown',
        backgroundColor: styles.supportPastelBrown,
        highlight: styles.supportBrown,
    },
    {
        identifier: 'supportPastelGrey',
        backgroundColor: styles.supportPastelGrey,
        highlight: styles.supportGreyDark,
    },
]);
/**
 * Allows querying HEX value of a color by its name.
 * These colors are found in palette used by Color Picker component.
 *
 * @example
 * ```
 * getHexByColorName('main', 'supportRed') === '#f55549'
 * ```
 *
 * @param {PaletteTypes} paletteName Possible values are 'main' | 'pastel'
 * @param colorName Possible values depend on `paletteName`.
 * For example, for `main` is can be `supportRed`, while for `pastel` is can be `supportPastelRed`.
 * TypeScript will provide full autocomplete.
 * @returns {string} the HEX representation of a color that Color Picker component is using.
 */
var getHexByColorName = function (paletteName, colorName) {
    if (paletteName === 'main') {
        var candidate_1 = mainPalette.find(function (_a) {
            var identifier = _a.identifier;
            return colorName === identifier;
        });
        return candidate_1.backgroundColor;
    }
    var candidate = pastelPalette.find(function (_a) {
        var identifier = _a.identifier;
        return colorName === identifier;
    });
    return candidate.backgroundColor;
};

var ColorPicker = function (_a) {
    var _b = _a.closeOnSelect, closeOnSelect = _b === void 0 ? false : _b, disabled = _a.disabled, initialColor = _a.initialColor, metadata = _a.metadata, onChange = _a.onChange, _c = _a.palette, palette = _c === void 0 ? 'main' : _c, title = _a.title;
    var wrapperRef = React.useRef(null);
    var colorPalette = palette === 'pastel' ? pastelPalette : mainPalette;
    var _d = React.useState(false), isPaletteOpen = _d[0], setIsPaletteOpen = _d[1];
    var _e = React.useState(initialColor === undefined ? colorPalette[0].backgroundColor : initialColor), currentColor = _e[0], setCurrentColor = _e[1];
    React.useEffect(function () {
        var onDocumentClick = function (e) {
            if (wrapperRef.current &&
                e.target instanceof Node &&
                !wrapperRef.current.contains(e.target)) {
                setIsPaletteOpen(false);
            }
        };
        window.document.addEventListener('mousedown', onDocumentClick);
        return function () {
            window.document.removeEventListener('mousedown', onDocumentClick);
        };
    }, []);
    var onColorClick = function (selectedColor) {
        onChange(selectedColor);
        setCurrentColor(selectedColor);
        if (closeOnSelect) {
            setIsPaletteOpen(false);
        }
    };
    return (React__default['default'].createElement("div", { className: styles.colorPicker, ref: wrapperRef },
        React__default['default'].createElement("button", __assign({}, utilsCommons.parseMetadata(metadata), { className: styles.button, disabled: disabled, onClick: function () { return setIsPaletteOpen(!isPaletteOpen); }, type: "button" }),
            React__default['default'].createElement("div", { className: styles.colorDot, "data-test-id": "selected-color", style: { background: currentColor } }),
            React__default['default'].createElement(icon.Icon, { className: styles.chevron, name: "sort-down", type: "solid" })),
        isPaletteOpen && (React__default['default'].createElement(panel.Panel, { className: styles.panel, absolute: true },
            React__default['default'].createElement("div", { className: styles.titleRow },
                React__default['default'].createElement(typography.Typography, { variant: "subtitle-2", className: styles.title }, title),
                React__default['default'].createElement("div", { className: styles.colorPreviewWrapper },
                    React__default['default'].createElement("div", { className: styles.colorPreview, style: { background: currentColor } }),
                    React__default['default'].createElement(typography.Typography, { variant: "body-1", className: styles.colorHex, component: "span" }, currentColor))),
            React__default['default'].createElement("div", { className: styles.optionRow }, colorPalette.map(function (_a) {
                var identifier = _a.identifier, backgroundColor = _a.backgroundColor, highlight = _a.highlight;
                return (React__default['default'].createElement("div", { className: styles.colorOption, "aria-label": "select-color-" + identifier, key: identifier, onClick: function () { return onColorClick(backgroundColor); }, onKeyDown: function (e) {
                        return e.key === 'Enter' && onColorClick(backgroundColor);
                    }, role: "button", style: { backgroundColor: backgroundColor, color: highlight }, tabIndex: 0 }));
            }))))));
};

exports.ColorPicker = ColorPicker;
exports.getHexByColorName = getHexByColorName;
//# sourceMappingURL=index.js.map
